@@ -1,7 +1,9 @@
-import requests
 from typing import Tuple, Union
-from . import IntegrationParser
+
+import requests
+
 from ..models import Integration
+from . import IntegrationParser
 
 
 class TypeUnknownParser(IntegrationParser):
@@ -12,5 +14,5 @@ class TypeUnknownParser(IntegrationParser):
     def invoke(
         self, request: requests.PreparedRequest, integration: Integration
     ) -> Tuple[int, Union[str, bytes]]:
-        _type = integration["type"]
-        raise NotImplementedError("The {0} type has not been implemented".format(_type))
+        _type = integration.integration_type
+        raise NotImplementedError(f"The {_type} type has not been implemented")
