@@ -1,3 +1,4 @@
+import re
 import time
 from collections import OrderedDict
 from enum import Enum, unique
@@ -7,11 +8,12 @@ from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
 from moto.ecs import ecs_backends
 from moto.moto_api._internal import mock_random
+from moto.utilities.utils import ARN_PARTITION_REGEX, get_partition
 
 from .exceptions import AWSValidationException
 
 if TYPE_CHECKING:
-    from moto.cloudwatch.models import FakeAlarm
+    from moto.cloudwatch.models import Alarm
 
 
 @unique
@@ -306,6 +308,7 @@ class ApplicationAutoscalingBackend(BaseBackend):
                 a
                 for a in self.scheduled_actions
                 if a.service_namespace == service_namespace
+                and a.scheduled_action_name == scheduled_action_name
                 and a.resource_id == resource_id
                 and a.scalable_dimension == scalable_dimension
             ),
@@ -378,7 +381,7 @@ def _get_resource_type_from_resource_id(resource_id: str) -> str:
     #    - ...except for sagemaker endpoints, dynamodb GSIs and keyspaces tables, where it's the third.
     #  - Comprehend uses an arn, with the resource type being the last element.
 
-    if resource_id.startswith("arn:aws:comprehend"):
+    if re.match(ARN_PARTITION_REGEX + ":comprehend", resource_id):
         resource_id = resource_id.split(":")[-1]
     resource_split = (
         resource_id.split("/") if "/" in resource_id else resource_id.split(":")
@@ -415,6 +418,7 @@ class FakeScalableTarget(BaseModel):
         self.role_arn = role_arn
         self.suspended_state = suspended_state
         self.creation_time = time.time()
+        self.arn = f"arn:{get_partition(backend.region_name)}:application-autoscaling:{backend.region_name}:{backend.account_id}:scalable-target/{mock_random.get_random_string(length=36, lower_case=True)}"
 
     def update(
         self,
@@ -463,9 +467,9 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
         self.policy_name = policy_name
         self.policy_type = policy_type
         self._guid = mock_random.uuid4()
-        self.policy_arn = f"arn:aws:autoscaling:{region_name}:{account_id}:scalingPolicy:{self._guid}:resource/{self.service_namespace}/{self.resource_id}:policyName/{self.policy_name}"
+        self.policy_arn = f"arn:{get_partition(region_name)}:autoscaling:{region_name}:{account_id}:scalingPolicy:{self._guid}:resource/{self.service_namespace}/{self.resource_id}:policyName/{self.policy_name}"
         self.creation_time = time.time()
-        self.alarms: List["FakeAlarm"] = []
+        self.alarms: List["Alarm"] = []
 
         self.account_id = account_id
         self.region_name = region_name
@@ -479,7 +483,7 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
             if self.service_namespace == "ecs":
                 self.alarms.extend(self._generate_ecs_alarms())
 
-    def _generate_dynamodb_alarms(self) -> List["FakeAlarm"]:
+    def _generate_dynamodb_alarms(self) -> List["Alarm"]:
         from moto.cloudwatch.models import CloudWatchBackend, cloudwatch_backends
 
         cloudwatch: CloudWatchBackend = cloudwatch_backends[self.account_id][
@@ -499,7 +503,7 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
             threshold=42.0,
             statistic="Sum",
             description=f"DO NOT EDIT OR DELETE. For TargetTrackingScaling policy {alarm_action}",
-            dimensions=[{"name": "TableName", "value": table_name}],
+            dimensions=[{"Name": "TableName", "Value": table_name}],
             alarm_actions=[alarm_action],
         )
         alarms.append(alarm1)
@@ -514,7 +518,7 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
             threshold=30.0,
             statistic="Sum",
             description=f"DO NOT EDIT OR DELETE. For TargetTrackingScaling policy {alarm_action}",
-            dimensions=[{"name": "TableName", "value": table_name}],
+            dimensions=[{"Name": "TableName", "Value": table_name}],
             alarm_actions=[alarm_action],
         )
         alarms.append(alarm2)
@@ -529,7 +533,7 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
             threshold=1.0,
             statistic="Average",
             description=f"DO NOT EDIT OR DELETE. For TargetTrackingScaling policy {alarm_action}",
-            dimensions=[{"name": "TableName", "value": table_name}],
+            dimensions=[{"Name": "TableName", "Value": table_name}],
             alarm_actions=[alarm_action],
         )
         alarms.append(alarm3)
@@ -544,19 +548,19 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
             threshold=1.0,
             statistic="Average",
             description=f"DO NOT EDIT OR DELETE. For TargetTrackingScaling policy {alarm_action}",
-            dimensions=[{"name": "TableName", "value": table_name}],
+            dimensions=[{"Name": "TableName", "Value": table_name}],
             alarm_actions=[alarm_action],
         )
         alarms.append(alarm4)
         return alarms
 
-    def _generate_ecs_alarms(self) -> List["FakeAlarm"]:
+    def _generate_ecs_alarms(self) -> List["Alarm"]:
         from moto.cloudwatch.models import CloudWatchBackend, cloudwatch_backends
 
         cloudwatch: CloudWatchBackend = cloudwatch_backends[self.account_id][
             self.region_name
         ]
-        alarms: List["FakeAlarm"] = []
+        alarms: List["Alarm"] = []
         alarm_action = f"{self.policy_arn}:createdBy/{mock_random.uuid4()}"
         config = self.target_tracking_scaling_policy_configuration or {}
         metric_spec = config.get("PredefinedMetricSpecification", {})
@@ -578,8 +582,8 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
             statistic="Average",
             description=f"DO NOT EDIT OR DELETE. For TargetTrackingScaling policy {alarm_action}",
             dimensions=[
-                {"name": "ClusterName", "value": cluster_name},
-                {"name": "ServiceName", "value": service_name},
+                {"Name": "ClusterName", "Value": cluster_name},
+                {"Name": "ServiceName", "Value": service_name},
             ],
             alarm_actions=[alarm_action],
         )
@@ -597,8 +601,8 @@ class FakeApplicationAutoscalingPolicy(BaseModel):
             statistic="Average",
             description=f"DO NOT EDIT OR DELETE. For TargetTrackingScaling policy {alarm_action}",
             dimensions=[
-                {"name": "ClusterName", "value": cluster_name},
-                {"name": "ServiceName", "value": service_name},
+                {"Name": "ClusterName", "Value": cluster_name},
+                {"Name": "ServiceName", "Value": service_name},
             ],
             alarm_actions=[alarm_action],
         )
@@ -638,7 +642,7 @@ class FakeScheduledAction(BaseModel):
         account_id: str,
         region: str,
     ) -> None:
-        self.arn = f"arn:aws:autoscaling:{region}:{account_id}:scheduledAction:{service_namespace}:scheduledActionName/{scheduled_action_name}"
+        self.arn = f"arn:{get_partition(region)}:autoscaling:{region}:{account_id}:scheduledAction:{service_namespace}/{resource_id}:scheduledActionName/{scheduled_action_name}"
         self.service_namespace = service_namespace
         self.schedule = schedule
         self.timezone = timezone
@@ -671,4 +675,6 @@ class FakeScheduledAction(BaseModel):
         self.end_time = end_time
 
 
-applicationautoscaling_backends = BackendDict(ApplicationAutoscalingBackend, "ec2")
+applicationautoscaling_backends = BackendDict(
+    ApplicationAutoscalingBackend, "application-autoscaling"
+)
