@@ -398,7 +398,7 @@ def parse_and_create_resource(
     resource = resource_class.create_from_cloudformation_json(
         resource_physical_name, resource_json, account_id, region_name, **kwargs
     )
-    resource.type = resource_type
+    resource.cf_resource_type = resource_type
     resource.logical_resource_id = logical_id
     return resource
 
@@ -427,7 +427,7 @@ def parse_and_update_resource(
             account_id=account_id,
             region_name=region_name,
         )
-        new_resource.type = resource_json["Type"]
+        new_resource.cf_resource_type = resource_json["Type"]
         new_resource.logical_resource_id = logical_id
         return new_resource
     else:
@@ -631,12 +631,9 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
                 if name == "AWS::Include":
                     location = params["Location"]
                     bucket_name, name = bucket_and_name_from_url(location)
-                    key = s3_backends[self._account_id][
-                        get_partition(self._region_name)
-                    ].get_object(
-                        bucket_name,  # type: ignore[arg-type]
-                        name,
-                    )
+                    partition = get_partition(self._region_name)
+                    backend = s3_backends[self._account_id][partition]
+                    key = backend.get_object(bucket_name, name)  # type: ignore[arg-type]
                     self._parsed_resources.update(json.loads(key.value))  # type: ignore[union-attr]
 
     def parse_ssm_parameter(self, value: str, value_type: str) -> str:
@@ -850,8 +847,14 @@ class ResourceMap(collections_abc.Mapping):  # type: ignore[type-arg]
             for logical_name in resource_names_by_action["Remove"].copy():
                 resource_json = self._resource_json_map[logical_name]
                 try:
-                    resource = self._parsed_resources[logical_name]
-                    self._delete_resource(resource, resource_json)
+                    if logical_name in self._parsed_resources:
+                        resource = self._parsed_resources[logical_name]
+                        self._delete_resource(resource, resource_json)
+                    else:
+                        # Resource wasn't created in the first place
+                        warnings.warn(
+                            f"Unable to delete {logical_name}, as it was never created"
+                        )
                 except Exception as e:
                     # skip over dependency violations, and try again in another pass
                     last_exception = e
