@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import datetime
 import inspect
 import re
@@ -7,11 +9,13 @@ from typing import Any, Callable, Dict, List, Optional, Tuple
 from urllib.parse import ParseResult, urlparse
 
 from botocore.exceptions import ClientError
-from botocore.loaders import create_loader
-from botocore.model import ServiceModel
+
+from moto.core.model import ServiceModel
 
 from ..settings import get_s3_custom_endpoints
 from .common_types import TYPE_RESPONSE
+from .constants import MISSING
+from .loaders import create_loader
 from .versions import PYTHON_311
 
 
@@ -173,6 +177,14 @@ def iso_8601_datetime_without_milliseconds_s3(
     return value.strftime("%Y-%m-%dT%H:%M:%S.000Z") if value else None
 
 
+RFC3339_DATETIME_PATTERN = re.compile(
+    r"^\d{4}-\d{2}-\d{2}"  # YYYY-MM-DD
+    r"[Tt]"  # 'T' or 't' separator
+    r"\d{2}:\d{2}:\d{2}"  # HH:MM:SS
+    r"(?:\.\d+)?"  # Optional fractional seconds (e.g., .123)
+    r"(?:[Zz]|(?:\+|-)\d{2}:\d{2})$"  # 'Z' or 'z' for UTC, or +/-HH:MM offset
+)
+
 RFC1123 = "%a, %d %b %Y %H:%M:%S GMT"
 EN_WEEKDAYS = ["Mon", "Tue", "Wed", "Thu", "Fri", "Sat", "Sun"]
 EN_MONTHS = [
@@ -460,3 +472,32 @@ def get_service_model(service_name: str) -> ServiceModel:
     model = loader.load_service_model(service_name, "service-2")
     service_model = ServiceModel(model, service_name)
     return service_model
+
+
+def get_value(obj: Any, key: int | str, default: Any = MISSING) -> Any:
+    """Helper for pulling a keyed value off various types of objects.
+
+    A key containing a dot (e.g. `parent.child`) will be treated as a
+    path to traverse to get to the desired value.
+    """
+    if not isinstance(key, int) and "." in key:
+        return _get_value_for_keys(obj, key.split("."), default)
+    return _get_value_for_key(obj, key, default)
+
+
+def _get_value_for_keys(obj: Any, keys: list[str], default: Any) -> Any:
+    if len(keys) == 1:
+        return _get_value_for_key(obj, keys[0], default)
+    return _get_value_for_keys(
+        _get_value_for_key(obj, keys[0], default), keys[1:], default
+    )
+
+
+def _get_value_for_key(obj: Any, key: int | str, default: Any) -> Any:
+    if not hasattr(obj, "__getitem__"):
+        return getattr(obj, str(key), default)
+
+    try:
+        return obj[key]
+    except (KeyError, IndexError, TypeError, AttributeError):
+        return default
