@@ -196,7 +196,7 @@ class InvalidCustomerGatewayIdError(EC2ClientError):
     def __init__(self, customer_gateway_id: str):
         super().__init__(
             "InvalidCustomerGatewayID.NotFound",
-            f"The customer gateway ID '{customer_gateway_id}' does not exist",
+            f"The customerGateway ID '{customer_gateway_id}' does not exist",
         )
 
 
@@ -254,6 +254,14 @@ class InvalidPermissionDuplicateError(EC2ClientError):
         )
 
 
+class DuplicateTransitGatewayAttachmentError(EC2ClientError):
+    def __init__(self, transit_gateway_id: str):
+        super().__init__(
+            "DuplicateTransitGatewayAttachment",
+            f"{transit_gateway_id} has non-deleted Transit Gateway Attachments with same VPC ID.",
+        )
+
+
 class InvalidRouteTableIdError(EC2ClientError):
     def __init__(self, route_table_id: str):
         super().__init__(
@@ -860,6 +868,14 @@ class InvalidCarrierGatewayID(EC2ClientError):
         )
 
 
+class InvalidTransitGatewayID(EC2ClientError):
+    def __init__(self, transit_gateway_id: str, msg: Optional[str] = None):
+        super().__init__(
+            "InvalidTransitGatewayID.NotFound",
+            msg or f"The transitGateway ID '{transit_gateway_id}' does not exist",
+        )
+
+
 class NoLoadBalancersProvided(EC2ClientError):
     def __init__(self) -> None:
         super().__init__(
