@@ -2,7 +2,8 @@ import hashlib
 from collections import OrderedDict
 from typing import Any, Dict, List
 
-from moto.core import BackendDict, BaseBackend, BaseModel
+from moto.core.base_backend import BackendDict, BaseBackend
+from moto.core.common_models import BaseModel
 
 from .exceptions import ClientError
 
