@@ -7,11 +7,11 @@ from email.encoders import encode_7or8bit
 from email.mime.base import MIMEBase
 from email.mime.multipart import MIMEMultipart
 from email.utils import formataddr, getaddresses, parseaddr
-from typing import Any, Dict, List, Optional
+from typing import Any, Dict, List, Literal, Optional
 
 from moto.core.base_backend import BackendDict, BaseBackend
 from moto.core.common_models import BaseModel
-from moto.core.utils import utcnow
+from moto.core.utils import iso_8601_datetime_with_milliseconds, utcnow
 from moto.sns.models import sns_backends
 from moto.utilities.paginator import paginate
 from moto.utilities.utils import get_partition
@@ -28,6 +28,7 @@ from .exceptions import (
     InvalidS3ConfigurationException,
     InvalidSnsTopicException,
     MessageRejectedError,
+    NotFoundException,
     RuleDoesNotExist,
     RuleSetDoesNotExist,
     TemplateDoesNotExist,
@@ -197,6 +198,163 @@ class ConfigurationSet(BaseModel):
         }
 
 
+class Contact(BaseModel):
+    def __init__(
+        self,
+        contact_list_name: str,
+        email_address: str,
+        topic_preferences: List[Dict[str, str]],
+        unsubscribe_all: bool,
+    ) -> None:
+        self.contact_list_name = contact_list_name
+        self.email_address = email_address
+        self.topic_default_preferences: List[Dict[str, str]] = []
+        self.topic_preferences = topic_preferences
+        self.unsubscribe_all = unsubscribe_all
+        self.created_timestamp = iso_8601_datetime_with_milliseconds()
+        self.last_updated_timestamp = iso_8601_datetime_with_milliseconds()
+
+    @property
+    def response_object(self) -> Dict[str, Any]:  # type: ignore[misc]
+        return {
+            "ContactListName": self.contact_list_name,
+            "EmailAddress": self.email_address,
+            "TopicDefaultPreferences": self.topic_default_preferences,
+            "TopicPreferences": self.topic_preferences,
+            "UnsubscribeAll": self.unsubscribe_all,
+            "CreatedTimestamp": self.created_timestamp,
+            "LastUpdatedTimestamp": self.last_updated_timestamp,
+        }
+
+
+class ContactList(BaseModel):
+    def __init__(
+        self,
+        contact_list_name: str,
+        description: str,
+        topics: List[Dict[str, str]],
+    ) -> None:
+        self.contact_list_name = contact_list_name
+        self.description = description
+        self.topics = topics
+        self.created_timestamp = iso_8601_datetime_with_milliseconds()
+        self.last_updated_timestamp = iso_8601_datetime_with_milliseconds()
+        self.contacts: Dict[str, Contact] = {}
+
+    def create_contact(self, contact_list_name: str, params: Dict[str, Any]) -> None:
+        email_address = params["EmailAddress"]
+        topic_preferences = (
+            [] if "TopicPreferences" not in params else params["TopicPreferences"]
+        )
+        unsubscribe_all = (
+            False if "UnsubscribeAll" not in params else params["UnsubscribeAll"]
+        )
+        new_contact = Contact(
+            contact_list_name, email_address, topic_preferences, unsubscribe_all
+        )
+        self.contacts[email_address] = new_contact
+
+    def list_contacts(self) -> List[Contact]:
+        return self.contacts.values()  # type: ignore[return-value]
+
+    def get_contact(self, email: str) -> Contact:
+        if email in self.contacts:
+            return self.contacts[email]
+        else:
+            raise NotFoundException(f"{email} doesn't exist in List.")
+
+    def delete_contact(self, email: str) -> None:
+        # delete if contact exists, otherwise get_contact will throw appropriate exception
+        if self.get_contact(email):
+            del self.contacts[email]
+
+    @property
+    def response_object(self) -> Dict[str, Any]:  # type: ignore[misc]
+        return {
+            "ContactListName": self.contact_list_name,
+            "Description": self.description,
+            "Topics": self.topics,
+            "CreatedTimestamp": self.created_timestamp,
+            "LastUpdatedTimestamp": self.last_updated_timestamp,
+        }
+
+
+class EmailIdentity(BaseModel):
+    def __init__(
+        self,
+        email_identity: str,
+        tags: Optional[Dict[str, str]],
+        dkim_signing_attributes: Optional[object],
+        configuration_set_name: Optional[str],
+    ) -> None:
+        self.email_identity = email_identity
+        self.tags = tags
+        self.dkim_signing_attributes = dkim_signing_attributes
+        self.configuration_set_name = configuration_set_name
+        self.identity_type = "EMAIL_ADDRESS" if "@" in email_identity else "DOMAIN"
+        self.verified_for_sending_status = False
+        self.feedback_forwarding_status = False
+        self.verification_status = "SUCCESS"
+        self.sending_enabled = True
+        self.dkim_attributes: Dict[str, Any] = {}
+        if not self.dkim_signing_attributes or not isinstance(
+            self.dkim_signing_attributes, dict
+        ):
+            self.dkim_attributes["SigningEnabled"] = False
+            self.dkim_attributes["Status"] = "NOT_STARTED"
+        else:
+            self.dkim_attributes["SigningEnabled"] = True
+            self.dkim_attributes["Status"] = "SUCCESS"
+            self.dkim_attributes["NextSigningKeyLength"] = (
+                self.dkim_signing_attributes.get("NextSigningKeyLength", "RSA_1024_BIT")
+            )
+            self.dkim_attributes["SigningAttributesOrigin"] = (
+                self.dkim_signing_attributes.get("SigningAttributesOrigin", "AWS_SES")
+            )
+            self.dkim_attributes["LastKeyGenerationTimestamp"] = (
+                iso_8601_datetime_with_milliseconds()
+            )
+        self.policies: Dict[str, Any] = {}
+
+    @property
+    def get_response_object(self) -> Dict[str, Any]:  # type: ignore[misc]
+        return {
+            "IdentityType": self.identity_type,
+            "FeedbackForwardingStatus": self.feedback_forwarding_status,
+            "VerifiedForSendingStatus": self.verified_for_sending_status,
+            "DkimAttributes": self.dkim_attributes,
+            "Policies": self.policies,
+            "Tags": self.tags,
+            "ConfigurationSetName": self.configuration_set_name,
+            "VerificationStatus": self.verification_status,
+        }
+
+    @property
+    def list_response_object(self) -> Dict[str, Any]:  # type: ignore[misc]
+        return {
+            "IdentityType": self.identity_type,
+            "IdentityName": self.email_identity,
+            "SendingEnabled": self.sending_enabled,
+            "VerificationStatus": self.verification_status,
+        }
+
+
+class DedicatedIpPool(BaseModel):
+    def __init__(
+        self, pool_name: str, scaling_mode: str, tags: List[Dict[str, str]]
+    ) -> None:
+        self.pool_name = pool_name
+        self.scaling_mode = scaling_mode
+        self.tags = tags
+
+    def to_dict(self) -> Dict[str, Any]:
+        return {
+            "PoolName": self.pool_name,
+            "Tags": self.tags,
+            "ScalingMode": self.scaling_mode,
+        }
+
+
 class SESBackend(BaseBackend):
     """
     Responsible for mocking calls to SES.
@@ -219,9 +377,6 @@ class SESBackend(BaseBackend):
 
     def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.addresses: List[str] = []
-        self.email_addresses: List[str] = []
-        self.domains: List[str] = []
         self.sent_messages: List[Any] = []
         self.sent_message_count = 0
         self.rejected_messages_count = 0
@@ -233,44 +388,72 @@ class SESBackend(BaseBackend):
         self.templates: Dict[str, Dict[str, str]] = {}
         self.receipt_rule_set: Dict[str, ReceiptRuleSet] = {}
         self.dkim_tokens: Dict[str, List[str]] = {}
+        self.contacts: Dict[str, Contact] = {}
+        self.contacts_lists: Dict[str, ContactList] = {}
+        self.email_identities: Dict[str, EmailIdentity] = {}
+        self.dedicated_ip_pools: Dict[str, DedicatedIpPool] = {}
 
     def _is_verified_address(self, source: str) -> bool:
         _, address = parseaddr(source)
-        if address in self.addresses:
-            return True
-        if address in self.email_addresses:
+        if address in self.email_identities:
             return True
         host = address.split("@", 1)[-1]
-        return host in self.domains
+        return host in self.email_identities
 
     def verify_email_identity(self, address: str) -> None:
         _, address = parseaddr(address)
-        if address not in self.addresses:
-            self.addresses.append(address)
+        if address not in self.email_identities:
+            self.create_email_identity_v2(address, None, None, None)
 
     def verify_email_address(self, address: str) -> None:
         _, address = parseaddr(address)
-        self.email_addresses.append(address)
+        if address not in self.email_identities:
+            self.create_email_identity_v2(address, None, None, None)
 
     def verify_domain(self, domain: str) -> None:
-        if domain.lower() not in self.domains:
-            self.domains.append(domain.lower())
+        if domain.lower() not in self.email_identities:
+            self.create_email_identity_v2(domain.lower(), None, None, None)
 
-    def list_identities(self, identity_type: str) -> List[str]:
-        if identity_type == "Domain":
-            return self.domains
-        if identity_type == "EmailAddress":
-            return self.addresses
-        return self.domains + self.addresses
+    def create_email_identity_v2(
+        self,
+        email_identity: str,
+        tags: Optional[Dict[str, str]],
+        dkim_signing_attributes: Optional[object],
+        configuration_set_name: Optional[str],
+    ) -> EmailIdentity:
+        identity = EmailIdentity(
+            email_identity=email_identity,
+            tags=tags,
+            dkim_signing_attributes=dkim_signing_attributes,
+            configuration_set_name=configuration_set_name,
+        )
+        self.email_identities[email_identity] = identity
+        return identity
+
+    def list_identities(
+        self, identity_type: Optional[Literal["EmailAddress", "Domain"]]
+    ) -> List[str]:
+        if identity_type is not None:
+            return [
+                (value.email_identity)
+                for _, value in self.email_identities.items()
+                if value.identity_type
+                == ("EMAIL_ADDRESS" if identity_type == "EmailAddress" else "DOMAIN")
+            ]
+        return [(value.email_identity) for _, value in self.email_identities.items()]
 
     def list_verified_email_addresses(self) -> List[str]:
-        return self.email_addresses
+        x = [
+            (value)
+            for _, value in self.email_identities.items()
+            if value.identity_type == "EMAIL_ADDRESS"
+        ]
+        y = [(identity.email_identity) for identity in x]
+        return y
 
     def delete_identity(self, identity: str) -> None:
-        if "@" in identity:
-            self.addresses.remove(identity)
-        else:
-            self.domains.remove(identity)
+        if self._is_verified_address(identity):
+            del self.email_identities[identity]
 
     def send_email(
         self, source: str, subject: str, body: str, destinations: Dict[str, List[str]]
@@ -528,7 +711,7 @@ class SESBackend(BaseBackend):
     ) -> ConfigurationSet:
         if configuration_set_name not in self.config_sets:
             raise ConfigurationSetDoesNotExist(
-                f"Configuration set <{configuration_set_name}> does not exist"
+                f"Configuration set <{configuration_set_name}> does not exist."
             )
         return self.config_sets[configuration_set_name]
 
@@ -668,16 +851,16 @@ class SESBackend(BaseBackend):
         # Validate ruleSetName
         self._validate_name_param(self.__RULE_SET_PARAM, rule_set_name)
         # Validate the name of the rule
-        self._validate_name_param(self.__RULE_PARAM, rule["name"])
+        self._validate_name_param(self.__RULE_PARAM, rule["Name"])
         # Start operating on the rule set, if it exists
         rule_set = self.receipt_rule_set.get(rule_set_name)
         if rule_set is None:
             raise RuleSetDoesNotExist(f"Rule set does not exist: {rule_set_name}")
         # If "after" is specified, then verify if a rule exists by that name under the rule set
-        if after and not any(r["name"] == after for r in rule_set.rules):
+        if after and not any(r["Name"] == after for r in rule_set.rules):
             raise RuleDoesNotExist(f"Rule does not exist: {after}")
         if rule in rule_set.rules:
-            raise AlreadyExists(f"Rule already exists: {rule['name']}")
+            raise AlreadyExists(f"Rule already exists: {rule['Name']}")
         # Validate the actions as part of the receipt_rule
         self._validate_receipt_rule_actions(rule)
         if not after:
@@ -686,7 +869,7 @@ class SESBackend(BaseBackend):
         else:
             # Find the position of the rule specified by after parameter
             for rule_idx, _ in enumerate(rule_set.rules):
-                if rule_set.rules[rule_idx]["name"] == after:
+                if rule_set.rules[rule_idx]["Name"] == after:
                     rule_set.rules.insert(rule_idx + 1, rule)
                     break
         self.receipt_rule_set[rule_set_name] = rule_set
@@ -770,14 +953,14 @@ class SESBackend(BaseBackend):
 
     def _validate_receipt_rule_actions(self, rule: Dict[str, Any]) -> None:
         # Allowed to be empty
-        actions = rule.get("actions", [])
+        actions = rule.get("Actions", [])
         for action in actions:
             if "S3Action" in action:
                 self._validate_s3_action(action["S3Action"])
             if "BounceAction" in action:
-                self._validate_sns_topic(action["BounceAction"].get("topic_arn"))
+                self._validate_sns_topic(action["BounceAction"].get("TopicArn"))
             if "WorkmailAction" in action:
-                self._validate_sns_topic(action["WorkmailAction"].get("topic_arn"))
+                self._validate_sns_topic(action["WorkmailAction"].get("TopicArn"))
             if "LambdaAction" in action:
                 self._validate_lambda_action(action["LambdaAction"])
 
@@ -787,20 +970,20 @@ class SESBackend(BaseBackend):
         # Raise an exception if the bucket does not exist
         try:
             partition = get_partition(self.region_name)
-            s3_backends[self.account_id][partition].get_bucket(s3_action["bucket_name"])
+            s3_backends[self.account_id][partition].get_bucket(s3_action["BucketName"])
         except Exception:
             raise InvalidS3ConfigurationException(
-                f"Could not write to bucket: {s3_action['bucket_name']}"
+                f"Could not write to bucket: {s3_action['BucketName']}"
             )
 
-        if s3_action.get("kms_key_arn"):
-            self._validate_kms_key(s3_action["kms_key_arn"])
+        if s3_action.get("KmsKeyArn"):
+            self._validate_kms_key(s3_action["KmsKeyArn"])
 
-        if s3_action.get("topic_arn"):
-            self._validate_sns_topic(s3_action["topic_arn"])
+        if s3_action.get("TopicArn"):
+            self._validate_sns_topic(s3_action["TopicArn"])
 
-        if s3_action.get("iam_role_arn"):
-            self._validate_iam_role(s3_action["iam_role_arn"])
+        if s3_action.get("IamRoleArn"):
+            self._validate_iam_role(s3_action["IamRoleArn"])
 
     def _validate_lambda_action(self, lambda_action: Dict[str, str]) -> None:
         from moto.awslambda.models import lambda_backends
@@ -808,14 +991,14 @@ class SESBackend(BaseBackend):
         # Raise an exception if the Lambda function does not exist
         try:
             _ = lambda_backends[self.account_id][self.region_name].get_function(
-                lambda_action["function_arn"]
+                lambda_action["FunctionArn"]
             )
         except Exception:
             raise InvalidLambdaFunctionException(
-                f"Invalid Lambda function: {lambda_action['function_arn']}"
+                f"Invalid Lambda function: {lambda_action['FunctionArn']}"
             )
 
-        self._validate_sns_topic(lambda_action.get("topic_arn"))
+        self._validate_sns_topic(lambda_action.get("TopicArn"))
 
     def _validate_kms_key(self, kms_key_arn: str) -> None:
         from moto.kms.models import kms_backends
@@ -867,7 +1050,7 @@ class SESBackend(BaseBackend):
             raise RuleSetDoesNotExist(f"Rule set does not exist: {rule_set_name}")
 
         for receipt_rule in rule_set.rules:
-            if receipt_rule["name"] == rule_name:
+            if receipt_rule["Name"] == rule_name:
                 return receipt_rule
 
         raise RuleDoesNotExist(f"Rule does not exist: {rule_name}")
@@ -879,11 +1062,11 @@ class SESBackend(BaseBackend):
             raise RuleSetDoesNotExist(f"Rule set does not exist: {rule_set_name}")
 
         for i, receipt_rule in enumerate(rule_set.rules):
-            if receipt_rule["name"] == rule["name"]:
+            if receipt_rule["Name"] == rule["Name"]:
                 rule_set.rules[i] = rule
                 break
         else:
-            raise RuleDoesNotExist(f"Rule does not exist: {rule['name']}")
+            raise RuleDoesNotExist(f"Rule does not exist: {rule['Name']}")
 
     def set_identity_mail_from_domain(
         self,
@@ -921,33 +1104,43 @@ class SESBackend(BaseBackend):
         self, identities: Optional[List[str]] = None
     ) -> Dict[str, Dict[str, str]]:
         if identities is None:
-            identities = []
+            actual_identities = []
+        else:
+            actual_identities = [
+                ident
+                for ident in self.email_identities.values()
+                if ident.email_identity in identities
+            ]
         attributes_by_identity = {}
-        for identity in identities:
-            if identity in (self.domains + self.addresses):
-                value = self.identity_mail_from_domains.get(identity, {})
-                mail_from_domain = value.get("mail_from_domain")
-                attributes_by_identity[identity] = {
-                    "MailFromDomain": mail_from_domain,
-                    "MailFromDomainStatus": "Success" if mail_from_domain else None,
-                    "BehaviorOnMXFailure": value.get(
-                        "behavior_on_mx_failure", "UseDefaultValue"
-                    ),
-                }
+        for identity in actual_identities:
+            value = self.identity_mail_from_domains.get(identity.email_identity, {})
+            mail_from_domain = value.get("mail_from_domain")
+            attributes_by_identity[identity.email_identity] = {
+                "MailFromDomain": mail_from_domain,
+                "MailFromDomainStatus": "Success" if mail_from_domain else None,
+                "BehaviorOnMXFailure": value.get(
+                    "behavior_on_mx_failure", "UseDefaultValue"
+                ),
+            }
         return attributes_by_identity
 
     def get_identity_verification_attributes(
         self, identities: Optional[List[str]] = None
     ) -> Dict[str, Dict[str, str]]:
         if identities is None:
-            identities = []
+            actual_identities = []
+        else:
+            actual_identities = [
+                ident
+                for ident in self.email_identities.values()
+                if ident.email_identity in identities
+            ]
         attributes_by_identity = {}
-        for identity in identities:
-            if identity in (self.domains + self.addresses):
-                attributes_by_identity[identity] = {
-                    "VerificationStatus": "Success",
-                    "VerificationToken": "ILQMESfEW0p6i6gIJcEWvO65TP5hg6B99hGFZ2lxrIs=",
-                }
+        for identity in actual_identities:
+            attributes_by_identity[identity.email_identity] = {
+                "VerificationStatus": "Success",
+                "VerificationToken": "ILQMESfEW0p6i6gIJcEWvO65TP5hg6B99hGFZ2lxrIs=",
+            }
         return attributes_by_identity
 
     def update_configuration_set_reputation_metrics_enabled(
@@ -966,12 +1159,26 @@ class SESBackend(BaseBackend):
         self, identities: List[str]
     ) -> Dict[str, Dict[str, Any]]:
         result = {}
-        for identity in identities:
-            is_domain = "@" not in identity
+        actual_identities: List[EmailIdentity] = []
+        for ident in identities:
+            if ident in self.email_identities.keys():
+                actual_identities.append(self.email_identities[ident])
+            else:
+                actual_identities.append(
+                    EmailIdentity(
+                        email_identity=ident,
+                        tags=None,
+                        dkim_signing_attributes=None,
+                        configuration_set_name=None,
+                    )
+                )
+
+        for identity in actual_identities:
+            is_domain = identity.identity_type == "DOMAIN"
             dkim_enabled = True
             verification_status = (
                 "Success"
-                if identity in (self.domains + self.addresses)
+                if identity.email_identity in self.email_identities.keys()
                 else "NotStarted"
             )
 
@@ -982,16 +1189,16 @@ class SESBackend(BaseBackend):
 
             # Only include tokens for domain identities
             if is_domain and verification_status == "Success":
-                if identity not in self.dkim_tokens:
+                if identity.email_identity not in self.dkim_tokens:
                     # Generate new DKIM tokens for the domain
-                    self.dkim_tokens[identity] = [
+                    self.dkim_tokens[identity.email_identity] = [
                         "vvjuipp74whm76gqoni7qmwwn4w4qusjiainivf6sf",
                         "3frqe7jn4obpuxjpwpolz6ipb3k5nvt2nhjpik2oy",
                         "wrqplteh7oodxnad7hsl4mixg2uavzneazxv5sxi2",
                     ]
-                dkim_data["DkimTokens"] = self.dkim_tokens[identity]
+                dkim_data["DkimTokens"] = self.dkim_tokens[identity.email_identity]
 
-            result[identity] = dkim_data
+            result[identity.email_identity] = dkim_data
 
         return result
 
